@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "aider" "0.13.2"
+(define-package "aider" "20250910.525"
   "AI assisted programming with Aider and LLM."
   '((emacs         "26.1")
     (transient     "0.9.0")
@@ -7,8 +7,8 @@
     (markdown-mode "2.5")
     (s             "1.13.0"))
   :url "https://github.com/tninja/aider.el"
-  :commit "6f6472586413f59cce992ecaa79276e3b56212ca"
-  :revdesc "v0.13.2-0-g6f6472586413"
+  :commit "7fc7041524f960bac46098dfcd23d096f8c7f0b9"
+  :revdesc "7fc7041524f9"
   :keywords '("ai" "gpt" "sonnet" "llm" "aider" "gemini-pro" "deepseek" "ai-assisted-coding")
   :authors '(("Kang Tu" . "tninja@gmail.com"))
   :maintainers '(("Kang Tu" . "tninja@gmail.com")))
